module LanguageServer
  module Protocol
    module Constant
      module PrepareSupportDefaultBehavior
        #
        # The client's default behavior is to select the identifier
        # according to the language's syntax rule.
        #
        IDENTIFIER = 1
      end
    end
  end
end
