module LanguageServer
  module Protocol
    module Constant
      module MessageType
        #
        # An error message.
        #
        ERROR = 1
        #
        # A warning message.
        #
        WARNING = 2
        #
        # An information message.
        #
        INFO = 3
        #
        # A log message.
        #
        LOG = 4
      end
    end
  end
end
