module LanguageServer
  module Protocol
    module Constant
      module DiagnosticSeverity
        #
        # Reports an error.
        #
        ERROR = 1
        #
        # Reports a warning.
        #
        WARNING = 2
        #
        # Reports an information.
        #
        INFORMATION = 3
        #
        # Reports a hint.
        #
        HINT = 4
      end
    end
  end
end
